# Generated by Django 4.0.1 on 2022-01-21 16:45

from django.contrib.postgres.operations import CreateExtension
from django.db import migrations


class PgStatStatementsExtension(CreateExtension):

    def __init__(self):
        self.name = 'pg_stat_statements'


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        PgStatStatementsExtension()
    ]
